@@ -1,7 +1,7 @@
 import json
 from dataclasses import asdict
 from io import BytesIO
-from typing import AsyncGenerator, List, Optional, cast
+from typing import Any, AsyncGenerator, Dict, List, Optional, Union, cast
 from uuid import uuid4
 
 from fastapi import APIRouter, File, Form, HTTPException, Query, UploadFile
@@ -14,8 +14,10 @@ from agno.media import File as FileMedia
 from agno.run.response import RunResponseErrorEvent
 from agno.run.team import RunResponseErrorEvent as TeamRunResponseErrorEvent
 from agno.run.team import TeamRunResponseEvent
+from agno.run.v2.workflow import WorkflowErrorEvent
 from agno.team.team import Team
 from agno.utils.log import logger
+from agno.workflow.v2.workflow import Workflow as WorkflowV2
 from agno.workflow.workflow import Workflow
 
 
@@ -83,6 +85,42 @@ async def team_chat_response_streamer(
         return
 
 
+async def workflow_response_streamer(
+    workflow: WorkflowV2,
+    body: Union[Dict[str, Any], str],
+    session_id: Optional[str] = None,
+    user_id: Optional[str] = None,
+) -> AsyncGenerator:
+    try:
+        if isinstance(body, dict):
+            run_response = await workflow.arun(  # type: ignore
+                **body,
+                user_id=user_id,
+                session_id=session_id,
+                stream=True,
+                stream_intermediate_steps=True,
+            )
+        else:
+            run_response = await workflow.arun(  # type: ignore
+                body,
+                user_id=user_id,
+                session_id=session_id,
+                stream=True,
+                stream_intermediate_steps=True,
+            )
+        async for run_response_chunk in run_response:
+            yield run_response_chunk.to_json()
+    except Exception as e:
+        import traceback
+
+        traceback.print_exc(limit=3)
+        error_response = WorkflowErrorEvent(
+            error=str(e),
+        )
+        yield error_response.to_json()
+        return
+
+
 def get_async_router(
     agents: Optional[List[Agent]] = None, teams: Optional[List[Team]] = None, workflows: Optional[List[Workflow]] = None
 ) -> APIRouter:
@@ -351,17 +389,24 @@ def get_async_router(
                     media_type="text/event-stream",
                 )
             elif workflow:
-                workflow_instance = workflow.deep_copy(update={"workflow_id": workflow_id})
-                workflow_instance.user_id = user_id
-                workflow_instance.session_name = None
-                if isinstance(workflow_input, dict):
-                    return StreamingResponse(
-                        (json.dumps(asdict(result)) for result in await workflow_instance.arun(**workflow_input)),
-                        media_type="text/event-stream",
-                    )
+                if isinstance(workflow, Workflow):
+                    workflow_instance = workflow.deep_copy(update={"workflow_id": workflow_id})
+                    workflow_instance.user_id = user_id
+                    workflow_instance.session_name = None
+
+                    if isinstance(workflow_input, dict):
+                        return StreamingResponse(
+                            (json.dumps(asdict(result)) for result in await workflow_instance.arun(**workflow_input)),
+                            media_type="text/event-stream",
+                        )
+                    else:
+                        return StreamingResponse(
+                            (json.dumps(asdict(result)) for result in await workflow_instance.arun(workflow_input)),  # type: ignore
+                            media_type="text/event-stream",
+                        )
                 else:
                     return StreamingResponse(
-                        (json.dumps(asdict(result)) for result in await workflow_instance.arun(workflow_input)),  # type: ignore
+                        workflow_response_streamer(workflow, workflow_input, session_id=session_id, user_id=user_id),  # type: ignore
                         media_type="text/event-stream",
                     )
         else:
@@ -392,12 +437,18 @@ def get_async_router(
                 )
                 return team_run_response.to_dict()
             elif workflow:
-                workflow_instance = workflow.deep_copy(update={"workflow_id": workflow_id})
-                workflow_instance.user_id = user_id
-                workflow_instance.session_name = None
-                if isinstance(workflow_input, dict):
-                    return (await workflow_instance.arun(**workflow_input)).to_dict()
+                if isinstance(workflow, Workflow):
+                    workflow_instance = workflow.deep_copy(update={"workflow_id": workflow_id})
+                    workflow_instance.user_id = user_id
+                    workflow_instance.session_name = None
+                    if isinstance(workflow_input, dict):
+                        return (await workflow_instance.arun(**workflow_input)).to_dict()
+                    else:
+                        return (await workflow_instance.arun(workflow_input)).to_dict()  # type: ignore
                 else:
-                    return (await workflow_instance.arun(workflow_input)).to_dict()  # type: ignore
+                    if isinstance(workflow_input, dict):
+                        return (await workflow.arun(**workflow_input, session_id=session_id, user_id=user_id)).to_dict()
+                    else:
+                        return (await workflow.arun(workflow_input, session_id=session_id, user_id=user_id)).to_dict()  # type: ignore
 
     return router
