@@ -77,16 +77,21 @@ class WebsiteReader(Reader):
         :param soup: The BeautifulSoup object to extract the main content from.
         :return: The main content.
         """
-        # Try to find main content by specific tags or class names
-        for tag in ["article", "main"]:
-            element = soup.find(tag)
-            if element:
-                return element.get_text(strip=True, separator=" ")
 
-        for class_name in ["content", "main-content", "post-content"]:
-            element = soup.find(class_=class_name)
-            if element:
-                return element.get_text(strip=True, separator=" ")
+        def match(tag: Tag) -> bool:
+            """
+            Check if the tag matches any of the relevant tags or class names
+            """
+            if tag.name in ["article", "main"]:
+                return True
+            if any(cls in ["content", "main-content", "post-content"] for cls in tag.get("class", [])):  # type: ignore
+                return True
+            return False
+
+        # Use a single call to 'find' with a custom function to match tags or classes
+        element = soup.find(match)
+        if element:
+            return element.get_text(strip=True, separator=" ")
 
         # If we only have a div without specific content classes, return empty string
         if soup.find("div") and not any(
