@@ -28,7 +28,8 @@ class CohereEmbedder(Embedder):
         client_params: Dict[str, Any] = {}
         if self.api_key:
             client_params["api_key"] = self.api_key
-        return CohereClient(**client_params)
+        self.cohere_client = CohereClient(**client_params)
+        return self.cohere_client
 
     def response(self, text: str) -> Union[EmbeddingsFloatsEmbedResponse, EmbeddingsByTypeEmbedResponse]:
         request_params: Dict[str, Any] = {}
