@@ -29,20 +29,21 @@ class MistralEmbedder(Embedder):
 
     @property
     def client(self) -> Mistral:
-        if not self.mistral_client:
-            _client_params: Dict[str, Any] = {}
-            if self.api_key:
-                _client_params["api_key"] = self.api_key
-            if self.endpoint:
-                _client_params["endpoint"] = self.endpoint
-            if self.max_retries is not None:
-                _client_params["max_retries"] = self.max_retries
-            if self.timeout is not None:
-                _client_params["timeout"] = self.timeout
-            if self.client_params:
-                _client_params.update(self.client_params)
+        if self.mistral_client:
+            return self.mistral_client
 
-            self.mistral_client = Mistral(**_client_params)
+        _client_params: Dict[str, Any] = {
+            "api_key": self.api_key,
+            "endpoint": self.endpoint,
+            "max_retries": self.max_retries,
+            "timeout": self.timeout,
+        }
+        _client_params = {k: v for k, v in _client_params.items() if v is not None}
+
+        if self.client_params:
+            _client_params.update(self.client_params)
+
+        self.mistral_client = Mistral(**_client_params)
 
         return self.mistral_client
 
