@@ -8,7 +8,7 @@ if TYPE_CHECKING:
 
 from agno.agent import RunResponse
 from agno.api.schemas.evals import EvalType
-from agno.eval.utils import log_eval_run, store_result_in_file
+from agno.eval.utils import async_log_eval_run, log_eval_run, store_result_in_file
 from agno.run.team import TeamRunResponse
 from agno.utils.log import logger
 
@@ -155,3 +155,96 @@ class ReliabilityEval:
 
         logger.debug(f"*********** Evaluation End: {self.eval_id} ***********")
         return self.result
+
+    async def arun(self, *, print_results: bool = False) -> Optional[ReliabilityResult]:
+        if self.agent_response is None and self.team_response is None:
+            raise ValueError("You need to provide 'agent_response' or 'team_response' to run the evaluation.")
+
+        if self.agent_response is not None and self.team_response is not None:
+            raise ValueError(
+                "You need to provide only one of 'agent_response' or 'team_response' to run the evaluation."
+            )
+
+        from rich.console import Console
+        from rich.live import Live
+        from rich.status import Status
+
+        # Add a spinner while running the evaluations
+        console = Console()
+        with Live(console=console, transient=True) as live_log:
+            status = Status("Running evaluation...", spinner="dots", speed=1.0, refresh_per_second=10)
+            live_log.update(status)
+
+            actual_tool_calls = None
+            if self.agent_response is not None:
+                messages = self.agent_response.messages
+            elif self.team_response is not None:
+                messages = self.team_response.messages or []
+                for member_response in self.team_response.member_responses:
+                    if member_response.messages is not None:
+                        messages += member_response.messages
+
+            for message in reversed(messages):  # type: ignore
+                if message.tool_calls:
+                    if actual_tool_calls is None:
+                        actual_tool_calls = message.tool_calls
+                    else:
+                        actual_tool_calls.append(message.tool_calls[0])  # type: ignore
+
+            failed_tool_calls = []
+            passed_tool_calls = []
+            for tool_call in actual_tool_calls:  # type: ignore
+                tool_name = tool_call.get("function", {}).get("name")
+                if not tool_name:
+                    continue
+                else:
+                    if tool_name not in self.expected_tool_calls:  # type: ignore
+                        failed_tool_calls.append(tool_call.get("function", {}).get("name"))
+                    else:
+                        passed_tool_calls.append(tool_call.get("function", {}).get("name"))
+
+            self.result = ReliabilityResult(
+                eval_status="PASSED" if len(failed_tool_calls) == 0 else "FAILED",
+                failed_tool_calls=failed_tool_calls,
+                passed_tool_calls=passed_tool_calls,
+            )
+
+        # Save result to file if requested
+        if self.file_path_to_save_results is not None and self.result is not None:
+            store_result_in_file(
+                file_path=self.file_path_to_save_results,
+                name=self.name,
+                eval_id=self.eval_id,
+                result=self.result,
+            )
+
+        # Print results if requested
+        if self.print_results or print_results:
+            self.result.print_eval(console)
+
+        # Log results to the Agno platform if requested
+        if self.monitoring:
+            if self.agent_response is not None:
+                agent_id = self.agent_response.agent_id
+                team_id = None
+                model_id = self.agent_response.model
+                model_provider = self.agent_response.model_provider
+            elif self.team_response is not None:
+                agent_id = None
+                team_id = self.team_response.team_id
+                model_id = self.team_response.model
+                model_provider = self.team_response.model_provider
+
+            await async_log_eval_run(
+                run_id=self.eval_id,  # type: ignore
+                run_data=asdict(self.result),
+                eval_type=EvalType.RELIABILITY,
+                name=self.name if self.name is not None else None,
+                agent_id=agent_id,
+                team_id=team_id,
+                model_id=model_id,
+                model_provider=model_provider,
+            )
+
+        logger.debug(f"*********** Evaluation End: {self.eval_id} ***********")
+        return self.result
