@@ -1,8 +1,15 @@
+from enum import Enum
 from typing import Any, Dict, Optional
 
 from pydantic import BaseModel
 
 
+class MemoryRetrieval(str, Enum):
+    last_n = "last_n"
+    first_n = "first_n"
+    semantic = "semantic"
+
+
 class Memory(BaseModel):
     """Model for Agent Memories"""
 
