@@ -20,6 +20,7 @@ class RedisMemoryDb(MemoryDb):
         port: int = 6379,
         db: int = 0,
         password: Optional[str] = None,
+        ssl: Optional[bool] = False,
         expire: Optional[int] = None,
     ):
         """
@@ -31,6 +32,7 @@ class RedisMemoryDb(MemoryDb):
             port (int): Redis port number
             db (int): Redis database number
             password (Optional[str]): Redis password if authentication is required
+            ssl (Optional[bool]): Whether to use SSL for Redis connection
             expire (Optional[int]): TTL (time to live) in seconds for Redis keys. None means no expiration.
         """
         self.prefix = prefix
@@ -41,6 +43,7 @@ class RedisMemoryDb(MemoryDb):
             db=db,
             password=password,
             decode_responses=True,  # Automatically decode responses to str
+            ssl=ssl,
         )
         log_debug(f"Created RedisMemoryDb with prefix: '{self.prefix}'")
 
