@@ -58,12 +58,7 @@ class OllamaTools(Ollama):
         Returns:
             Dict[str, Any]: The API kwargs for the model.
         """
-        base_params: Dict[str, Any] = {
-            "format": self.format,
-            "options": self.options,
-            "keep_alive": self.keep_alive,
-            "request_params": self.request_params,
-        }
+        base_params: Dict[str, Any] = {"format": self.format, "options": self.options, "keep_alive": self.keep_alive}
         request_params: Dict[str, Any] = {k: v for k, v in base_params.items() if v is not None}
         # Add additional request params if provided
         if self.request_params:
