@@ -17,6 +17,7 @@ class RunEvent(str, Enum):
 
     run_started = "RunStarted"
     run_response_content = "RunResponseContent"
+    run_intermediate_response_content = "RunIntermediateResponseContent"
     run_completed = "RunCompleted"
     run_error = "RunError"
     run_cancelled = "RunCancelled"
@@ -34,6 +35,12 @@ class RunEvent(str, Enum):
     memory_update_started = "MemoryUpdateStarted"
     memory_update_completed = "MemoryUpdateCompleted"
 
+    parser_model_response_started = "ParserModelResponseStarted"
+    parser_model_response_completed = "ParserModelResponseCompleted"
+
+    output_model_response_started = "OutputModelResponseStarted"
+    output_model_response_completed = "OutputModelResponseCompleted"
+
 
 @dataclass
 class BaseAgentRunResponseEvent(BaseRunResponseEvent):
@@ -44,10 +51,23 @@ class BaseAgentRunResponseEvent(BaseRunResponseEvent):
     run_id: Optional[str] = None
     session_id: Optional[str] = None
     team_session_id: Optional[str] = None
+    tools: Optional[List[ToolExecution]] = None
 
     # For backwards compatibility
     content: Optional[Any] = None
 
+    @property
+    def tools_requiring_confirmation(self):
+        return [t for t in self.tools if t.requires_confirmation] if self.tools else []
+
+    @property
+    def tools_requiring_user_input(self):
+        return [t for t in self.tools if t.requires_user_input] if self.tools else []
+
+    @property
+    def tools_awaiting_external_execution(self):
+        return [t for t in self.tools if t.external_execution_required] if self.tools else []
+
 
 @dataclass
 class RunResponseStartedEvent(BaseAgentRunResponseEvent):
@@ -66,12 +86,20 @@ class RunResponseContentEvent(BaseAgentRunResponseEvent):
     content: Optional[Any] = None
     content_type: str = "str"
     thinking: Optional[str] = None
+    reasoning_content: Optional[str] = None
     citations: Optional[Citations] = None
     response_audio: Optional[AudioResponse] = None  # Model audio response
     image: Optional[ImageArtifact] = None  # Image attached to the response
     extra_data: Optional[RunResponseExtraData] = None
 
 
+@dataclass
+class IntermediateRunResponseContentEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.run_intermediate_response_content.value
+    content: Optional[Any] = None
+    content_type: str = "str"
+
+
 @dataclass
 class RunResponseCompletedEvent(BaseAgentRunResponseEvent):
     event: str = RunEvent.run_completed.value
@@ -164,9 +192,30 @@ class ToolCallCompletedEvent(BaseAgentRunResponseEvent):
     audio: Optional[List[AudioArtifact]] = None  # Audio produced by the tool call
 
 
+@dataclass
+class ParserModelResponseStartedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.parser_model_response_started.value
+
+
+@dataclass
+class ParserModelResponseCompletedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.parser_model_response_completed.value
+
+
+@dataclass
+class OutputModelResponseStartedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.output_model_response_started.value
+
+
+@dataclass
+class OutputModelResponseCompletedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.output_model_response_completed.value
+
+
 RunResponseEvent = Union[
     RunResponseStartedEvent,
     RunResponseContentEvent,
+    IntermediateRunResponseContentEvent,
     RunResponseCompletedEvent,
     RunResponseErrorEvent,
     RunResponseCancelledEvent,
@@ -179,6 +228,10 @@ RunResponseEvent = Union[
     MemoryUpdateCompletedEvent,
     ToolCallStartedEvent,
     ToolCallCompletedEvent,
+    ParserModelResponseStartedEvent,
+    ParserModelResponseCompletedEvent,
+    OutputModelResponseStartedEvent,
+    OutputModelResponseCompletedEvent,
 ]
 
 
@@ -186,6 +239,7 @@ RunResponseEvent = Union[
 RUN_EVENT_TYPE_REGISTRY = {
     RunEvent.run_started.value: RunResponseStartedEvent,
     RunEvent.run_response_content.value: RunResponseContentEvent,
+    RunEvent.run_intermediate_response_content.value: IntermediateRunResponseContentEvent,
     RunEvent.run_completed.value: RunResponseCompletedEvent,
     RunEvent.run_error.value: RunResponseErrorEvent,
     RunEvent.run_cancelled.value: RunResponseCancelledEvent,
@@ -198,6 +252,10 @@ RUN_EVENT_TYPE_REGISTRY = {
     RunEvent.memory_update_completed.value: MemoryUpdateCompletedEvent,
     RunEvent.tool_call_started.value: ToolCallStartedEvent,
     RunEvent.tool_call_completed.value: ToolCallCompletedEvent,
+    RunEvent.parser_model_response_started.value: ParserModelResponseStartedEvent,
+    RunEvent.parser_model_response_completed.value: ParserModelResponseCompletedEvent,
+    RunEvent.output_model_response_started.value: OutputModelResponseStartedEvent,
+    RunEvent.output_model_response_completed.value: OutputModelResponseCompletedEvent,
 }
 
 
@@ -362,16 +420,16 @@ class RunResponse:
         messages = data.pop("messages", None)
         messages = [Message.model_validate(message) for message in messages] if messages else None
 
-        tools = data.pop("tools", None)
+        tools = data.pop("tools", [])
         tools = [ToolExecution.from_dict(tool) for tool in tools] if tools else None
 
-        images = data.pop("images", None)
+        images = data.pop("images", [])
         images = [ImageArtifact.model_validate(image) for image in images] if images else None
 
-        videos = data.pop("videos", None)
+        videos = data.pop("videos", [])
         videos = [VideoArtifact.model_validate(video) for video in videos] if videos else None
 
-        audio = data.pop("audio", None)
+        audio = data.pop("audio", [])
         audio = [AudioArtifact.model_validate(audio) for audio in audio] if audio else None
 
         response_audio = data.pop("response_audio", None)
