@@ -17,6 +17,7 @@ class TeamRunEvent(str, Enum):
 
     run_started = "TeamRunStarted"
     run_response_content = "TeamRunResponseContent"
+    run_intermediate_response_content = "TeamRunIntermediateResponseContent"
     run_completed = "TeamRunCompleted"
     run_error = "TeamRunError"
     run_cancelled = "TeamRunCancelled"
@@ -31,6 +32,12 @@ class TeamRunEvent(str, Enum):
     memory_update_started = "TeamMemoryUpdateStarted"
     memory_update_completed = "TeamMemoryUpdateCompleted"
 
+    parser_model_response_started = "TeamParserModelResponseStarted"
+    parser_model_response_completed = "TeamParserModelResponseCompleted"
+
+    output_model_response_started = "TeamOutputModelResponseStarted"
+    output_model_response_completed = "TeamOutputModelResponseCompleted"
+
 
 @dataclass
 class BaseTeamRunResponseEvent(BaseRunResponseEvent):
@@ -88,6 +95,13 @@ class RunResponseContentEvent(BaseTeamRunResponseEvent):
     extra_data: Optional[RunResponseExtraData] = None
 
 
+@dataclass
+class IntermediateRunResponseContentEvent(BaseTeamRunResponseEvent):
+    event: str = TeamRunEvent.run_intermediate_response_content.value
+    content: Optional[Any] = None
+    content_type: str = "str"
+
+
 @dataclass
 class RunResponseCompletedEvent(BaseTeamRunResponseEvent):
     event: str = TeamRunEvent.run_completed.value
@@ -162,9 +176,30 @@ class ToolCallCompletedEvent(BaseTeamRunResponseEvent):
     audio: Optional[List[AudioArtifact]] = None  # Audio produced by the tool call
 
 
+@dataclass
+class ParserModelResponseStartedEvent(BaseTeamRunResponseEvent):
+    event: str = TeamRunEvent.parser_model_response_started.value
+
+
+@dataclass
+class ParserModelResponseCompletedEvent(BaseTeamRunResponseEvent):
+    event: str = TeamRunEvent.parser_model_response_completed.value
+
+
+@dataclass
+class OutputModelResponseStartedEvent(BaseTeamRunResponseEvent):
+    event: str = TeamRunEvent.output_model_response_started.value
+
+
+@dataclass
+class OutputModelResponseCompletedEvent(BaseTeamRunResponseEvent):
+    event: str = TeamRunEvent.output_model_response_completed.value
+
+
 TeamRunResponseEvent = Union[
     RunResponseStartedEvent,
     RunResponseContentEvent,
+    IntermediateRunResponseContentEvent,
     RunResponseCompletedEvent,
     RunResponseErrorEvent,
     RunResponseCancelledEvent,
@@ -175,12 +210,17 @@ TeamRunResponseEvent = Union[
     MemoryUpdateCompletedEvent,
     ToolCallStartedEvent,
     ToolCallCompletedEvent,
+    ParserModelResponseStartedEvent,
+    ParserModelResponseCompletedEvent,
+    OutputModelResponseStartedEvent,
+    OutputModelResponseCompletedEvent,
 ]
 
 # Map event string to dataclass for team events
 TEAM_RUN_EVENT_TYPE_REGISTRY = {
     TeamRunEvent.run_started.value: RunResponseStartedEvent,
     TeamRunEvent.run_response_content.value: RunResponseContentEvent,
+    TeamRunEvent.run_intermediate_response_content.value: IntermediateRunResponseContentEvent,
     TeamRunEvent.run_completed.value: RunResponseCompletedEvent,
     TeamRunEvent.run_error.value: RunResponseErrorEvent,
     TeamRunEvent.run_cancelled.value: RunResponseCancelledEvent,
@@ -191,6 +231,10 @@ TEAM_RUN_EVENT_TYPE_REGISTRY = {
     TeamRunEvent.memory_update_completed.value: MemoryUpdateCompletedEvent,
     TeamRunEvent.tool_call_started.value: ToolCallStartedEvent,
     TeamRunEvent.tool_call_completed.value: ToolCallCompletedEvent,
+    TeamRunEvent.parser_model_response_started.value: ParserModelResponseStartedEvent,
+    TeamRunEvent.parser_model_response_completed.value: ParserModelResponseCompletedEvent,
+    TeamRunEvent.output_model_response_started.value: OutputModelResponseStartedEvent,
+    TeamRunEvent.output_model_response_completed.value: OutputModelResponseCompletedEvent,
 }
 
 
@@ -344,9 +388,9 @@ class TeamRunResponse:
         messages = data.pop("messages", None)
         messages = [Message.model_validate(message) for message in messages] if messages else None
 
-        member_responses = data.pop("member_responses", None)
+        member_responses = data.pop("member_responses", [])
         parsed_member_responses: List[Union["TeamRunResponse", RunResponse]] = []
-        if member_responses is not None:
+        if member_responses:
             for response in member_responses:
                 if "agent_id" in response:
                     parsed_member_responses.append(RunResponse.from_dict(response))
@@ -357,16 +401,16 @@ class TeamRunResponse:
         if extra_data is not None:
             extra_data = RunResponseExtraData.from_dict(extra_data)
 
-        images = data.pop("images", None)
+        images = data.pop("images", [])
         images = [ImageArtifact.model_validate(image) for image in images] if images else None
 
-        videos = data.pop("videos", None)
+        videos = data.pop("videos", [])
         videos = [VideoArtifact.model_validate(video) for video in videos] if videos else None
 
-        audio = data.pop("audio", None)
+        audio = data.pop("audio", [])
         audio = [AudioArtifact.model_validate(audio) for audio in audio] if audio else None
 
-        tools = data.pop("tools", None)
+        tools = data.pop("tools", [])
         tools = [ToolExecution.from_dict(tool) for tool in tools] if tools else None
 
         response_audio = data.pop("response_audio", None)
