@@ -8,6 +8,7 @@ from agno.storage.base import Storage
 from agno.storage.session import Session
 from agno.storage.session.agent import AgentSession
 from agno.storage.session.team import TeamSession
+from agno.storage.session.v2.workflow import WorkflowSession as WorkflowSessionV2
 from agno.storage.session.workflow import WorkflowSession
 from agno.utils.log import log_debug, log_info, logger
 
@@ -32,7 +33,7 @@ class RedisStorage(Storage):
         port: int = 6379,
         db: int = 0,
         password: Optional[str] = None,
-        mode: Optional[Literal["agent", "team", "workflow"]] = "agent",
+        mode: Optional[Literal["agent", "team", "workflow", "workflow_v2"]] = "agent",
         ssl: Optional[bool] = False,
         expire: Optional[int] = None,
     ):
@@ -45,7 +46,7 @@ class RedisStorage(Storage):
             port (int): Redis port number
             db (int): Redis database number
             password (Optional[str]): Redis password if authentication is required
-            mode (Optional[Literal["agent", "team", "workflow"]]): Storage mode
+            mode (Optional[Literal["agent", "team", "workflow", "workflow_v2"]]): Storage mode
             ssl (Optional[bool]): Whether to use SSL for Redis connection
             expire (Optional[int]): TTL (time to live) in seconds for Redis keys. None means no expiration.
         """
@@ -104,6 +105,8 @@ class RedisStorage(Storage):
                 return TeamSession.from_dict(session_data)
             elif self.mode == "workflow":
                 return WorkflowSession.from_dict(session_data)
+            elif self.mode == "workflow_v2":
+                return WorkflowSessionV2.from_dict(session_data)
 
         except Exception as e:
             logger.error(f"Error reading session: {e}")
@@ -128,6 +131,8 @@ class RedisStorage(Storage):
                             self.mode == "workflow" and data["workflow_id"] == entity_id and data["user_id"] == user_id
                         ):
                             session_ids.append(data["session_id"])
+                        elif self.mode == "workflow_v2" and data["workflow_id"] == entity_id:
+                            session_ids.append(data["session_id"])
                     elif user_id and data["user_id"] == user_id:
                         session_ids.append(data["session_id"])
                     elif entity_id:
@@ -137,6 +142,8 @@ class RedisStorage(Storage):
                             session_ids.append(data["session_id"])
                         elif self.mode == "workflow" and data["workflow_id"] == entity_id:
                             session_ids.append(data["session_id"])
+                        elif self.mode == "workflow_v2" and data["workflow_id"] == entity_id:
+                            session_ids.append(data["session_id"])
                 else:
                     # No filters applied, add all session_ids
                     session_ids.append(data["session_id"])
@@ -166,6 +173,8 @@ class RedisStorage(Storage):
                             self.mode == "workflow" and data["workflow_id"] == entity_id and data["user_id"] == user_id
                         ):
                             _session = WorkflowSession.from_dict(data)
+                        elif self.mode == "workflow_v2" and data["workflow_id"] == entity_id:
+                            _session = WorkflowSessionV2.from_dict(data)
                     elif user_id and data["user_id"] == user_id:
                         if self.mode == "agent":
                             _session = AgentSession.from_dict(data)
@@ -173,6 +182,8 @@ class RedisStorage(Storage):
                             _session = TeamSession.from_dict(data)
                         elif self.mode == "workflow":
                             _session = WorkflowSession.from_dict(data)
+                        elif self.mode == "workflow_v2" and data["workflow_id"] == entity_id:
+                            _session = WorkflowSessionV2.from_dict(data)
                     elif entity_id:
                         if self.mode == "agent" and data["agent_id"] == entity_id:
                             _session = AgentSession.from_dict(data)
@@ -180,6 +191,8 @@ class RedisStorage(Storage):
                             _session = TeamSession.from_dict(data)
                         elif self.mode == "workflow" and data["workflow_id"] == entity_id:
                             _session = WorkflowSession.from_dict(data)
+                        elif self.mode == "workflow_v2" and data["workflow_id"] == entity_id:
+                            _session = WorkflowSessionV2.from_dict(data)
 
                     if _session:
                         sessions.append(_session)
@@ -192,6 +205,8 @@ class RedisStorage(Storage):
                         _session = TeamSession.from_dict(data)
                     elif self.mode == "workflow":
                         _session = WorkflowSession.from_dict(data)
+                    elif self.mode == "workflow_v2":
+                        _session = WorkflowSessionV2.from_dict(data)
                     if _session:
                         sessions.append(_session)
 
@@ -237,7 +252,8 @@ class RedisStorage(Storage):
                             continue
                         elif self.mode == "workflow" and data["workflow_id"] != entity_id:
                             continue
-
+                        elif self.mode == "workflow_v2" and data["workflow_id"] != entity_id:
+                            continue
                     # Store with created_at for sorting
                     created_at = data.get("created_at", 0)
                     session_data.append((created_at, data))
@@ -260,7 +276,8 @@ class RedisStorage(Storage):
                     session = TeamSession.from_dict(data)
                 elif self.mode == "workflow":
                     session = WorkflowSession.from_dict(data)
-
+                elif self.mode == "workflow_v2":
+                    session = WorkflowSessionV2.from_dict(data)
                 if session is not None:
                     sessions.append(session)
 
@@ -272,9 +289,12 @@ class RedisStorage(Storage):
     def upsert(self, session: Session) -> Optional[Session]:
         """Insert or update a Session in Redis."""
         try:
-            data = asdict(session)
+            if self.mode == "workflow_v2":
+                data = session.to_dict()
+            else:
+                data = asdict(session)
             data["updated_at"] = int(time.time())
-            if "created_at" not in data:
+            if "created_at" not in data or data["created_at"] is None:
                 data["created_at"] = data["updated_at"]
 
             key = self._get_key(session.session_id)
