@@ -16,6 +16,8 @@ class AgentSession:
     user_id: Optional[str] = None
     # ID of the team session this agent session is associated with
     team_session_id: Optional[str] = None
+    # ID of the workflow session this agent session is associated with
+    workflow_session_id: Optional[str] = None
     # Agent Memory
     memory: Optional[Dict[str, Any]] = None
     # Session Data: session_name, session_state, images, videos, audio
@@ -51,6 +53,7 @@ class AgentSession:
             session_id=data.get("session_id"),  # type: ignore
             agent_id=data.get("agent_id"),
             team_session_id=data.get("team_session_id"),
+            workflow_session_id=data.get("workflow_session_id"),
             user_id=data.get("user_id"),
             memory=data.get("memory"),
             agent_data=data.get("agent_data"),
