@@ -26,6 +26,9 @@ class AWSLambdaTools(Toolkit):
         super().__init__(name="aws-lambda", tools=tools, **kwargs)
 
     def list_functions(self) -> str:
+        """
+        List all AWS Lambda functions in the configured AWS account.
+        """
         try:
             response = self.client.list_functions()
             functions = [func["FunctionName"] for func in response["Functions"]]
@@ -34,6 +37,13 @@ class AWSLambdaTools(Toolkit):
             return f"Error listing functions: {str(e)}"
 
     def invoke_function(self, function_name: str, payload: str = "{}") -> str:
+        """
+        Invoke a specific AWS Lambda function with an optional JSON payload.
+
+        Args:
+            function_name (str): The name of the Lambda function to invoke.
+            payload (str): The JSON payload to send to the function. Defaults to "{}".
+        """
         try:
             response = self.client.invoke(FunctionName=function_name, Payload=payload)
             return f"Function invoked successfully. Status code: {response['StatusCode']}, Payload: {response['Payload'].read().decode('utf-8')}"
