@@ -15,10 +15,11 @@ class NewspaperTools(Toolkit):
     """
 
     def __init__(self, get_article_text: bool = True, **kwargs):
-        super().__init__(name="newspaper_toolkit", **kwargs)
-
+        tools = []
         if get_article_text:
-            self.register(self.get_article_text)
+            tools.append(self.get_article_text)
+
+        super().__init__(name="newspaper_toolkit", tools=tools, **kwargs)
 
     def get_article_text(self, url: str) -> str:
         """Get the text of an article from a URL.
