@@ -1,5 +1,5 @@
 from textwrap import dedent
-from typing import Optional, Union
+from typing import Any, List, Optional, Union
 
 from agno.agent import Agent
 from agno.reasoning.step import NextAction, ReasoningStep
@@ -20,12 +20,6 @@ class ReasoningTools(Toolkit):
         **kwargs,
     ):
         """A toolkit that provides step-by-step reasoning tools: Think and Analyze."""
-        super().__init__(
-            name="reasoning_tools",
-            instructions=instructions,
-            add_instructions=add_instructions,
-            **kwargs,
-        )
 
         # Add instructions for using this toolkit
         if instructions is None:
@@ -36,12 +30,22 @@ class ReasoningTools(Toolkit):
                 else:
                     self.instructions += "\n" + self.FEW_SHOT_EXAMPLES
             self.instructions += "\n</reasoning_instructions>\n"
+        else:
+            self.instructions = instructions
 
-        # Register each tool based on the init flags
+        tools: List[Any] = []
         if think:
-            self.register(self.think)
+            tools.append(self.think)
         if analyze:
-            self.register(self.analyze)
+            tools.append(self.analyze)
+
+        super().__init__(
+            name="reasoning_tools",
+            instructions=self.instructions,
+            add_instructions=add_instructions,
+            tools=tools,
+            **kwargs,
+        )
 
     def think(
         self, agent: Union[Agent, Team], title: str, thought: str, action: Optional[str] = None, confidence: float = 0.8
