@@ -5,7 +5,7 @@ try:
 except ImportError:
     raise ImportError("`spider-client` not installed. Please install using `pip install spider-client`")
 
-from typing import Optional
+from typing import Any, List, Optional
 
 from agno.tools.toolkit import Toolkit
 from agno.utils.log import log_info, logger
@@ -19,13 +19,16 @@ class SpiderTools(Toolkit):
         optional_params: Optional[dict] = None,
         **kwargs,
     ):
-        super().__init__(name="spider", **kwargs)
         self.max_results = max_results
         self.url = url
         self.optional_params = optional_params or {}
-        self.register(self.search)
-        self.register(self.scrape)
-        self.register(self.crawl)
+
+        tools: List[Any] = []
+        tools.append(self.search)
+        tools.append(self.scrape)
+        tools.append(self.crawl)
+
+        super().__init__(name="spider", tools=tools, **kwargs)
 
     def search(self, query: str, max_results: int = 5) -> str:
         """Use this function to search the web.
