@@ -1,4 +1,5 @@
 import webbrowser
+from typing import Any, List
 
 from agno.tools import Toolkit
 
@@ -7,8 +8,10 @@ class WebBrowserTools(Toolkit):
     """Tools for opening a page on the web browser"""
 
     def __init__(self):
-        super().__init__(name="webbrowser_tools")
-        self.register(self.open_page)
+        tools: List[Any] = []
+        tools.append(self.open_page)
+
+        super().__init__(name="webbrowser_tools", tools=tools)
 
     def open_page(self, url: str, new_window: bool = False):
         """Open a URL in a browser window
