@@ -3,7 +3,7 @@ from datetime import date, datetime
 from pathlib import Path
 from typing import Dict, List, Optional, Union
 
-from agno.utils.log import logger
+from agno.utils.log import log_debug
 
 
 class CustomJSONEncoder(json.JSONEncoder):
@@ -19,12 +19,12 @@ class CustomJSONEncoder(json.JSONEncoder):
 
 def read_json_file(file_path: Optional[Path]) -> Optional[Union[Dict, List]]:
     if file_path is not None and file_path.exists() and file_path.is_file():
-        # logger.debug(f"Reading {file_path}")
+        # log_debug(f"Reading {file_path}")
         return json.loads(file_path.read_text())
     return None
 
 
 def write_json_file(file_path: Optional[Path], data: Optional[Union[Dict, List]], **kwargs) -> None:
     if file_path is not None and data is not None:
-        logger.debug(f"Writing {file_path}")
+        log_debug(f"Writing {file_path}")
         file_path.write_text(json.dumps(data, cls=CustomJSONEncoder, indent=4, **kwargs))
