@@ -5,13 +5,20 @@ from pydantic import BaseModel
 
 from agno.run.response import RunResponse, RunResponseEvent
 from agno.run.team import TeamRunResponse, TeamRunResponseEvent
-from agno.run.workflow import WorkflowRunResponseEvent
+from agno.run.v2.workflow import WorkflowRunResponse, WorkflowRunResponseEvent
 from agno.utils.log import logger
 from agno.utils.timer import Timer
 
 
 def pprint_run_response(
-    run_response: Union[RunResponse, Iterable[RunResponseEvent], TeamRunResponse, Iterable[TeamRunResponseEvent]],
+    run_response: Union[
+        RunResponse,
+        Iterable[RunResponseEvent],
+        TeamRunResponse,
+        Iterable[TeamRunResponseEvent],
+        WorkflowRunResponse,
+        Iterable[WorkflowRunResponseEvent],
+    ],
     markdown: bool = False,
     show_time: bool = False,
 ) -> None:
@@ -25,7 +32,11 @@ def pprint_run_response(
     from agno.cli.console import console
 
     # If run_response is a single RunResponse, wrap it in a list to make it iterable
-    if isinstance(run_response, RunResponse) or isinstance(run_response, TeamRunResponse):
+    if (
+        isinstance(run_response, RunResponse)
+        or isinstance(run_response, TeamRunResponse)
+        or isinstance(run_response, WorkflowRunResponse)
+    ):
         single_response_content: Union[str, JSON, Markdown] = ""
         if isinstance(run_response.content, str):
             single_response_content = (
@@ -60,9 +71,17 @@ def pprint_run_response(
                         or isinstance(resp, tuple(get_args(WorkflowRunResponseEvent)))
                     )
                     and hasattr(resp, "content")
-                    and isinstance(resp.content, str)
+                    and resp.content is not None
                 ):
-                    streaming_response_content += resp.content
+                    if isinstance(resp.content, BaseModel):
+                        try:
+                            JSON(resp.content.model_dump_json(exclude_none=True), indent=2)  # type: ignore
+                        except Exception as e:
+                            logger.warning(f"Failed to convert response to Markdown: {e}")
+                    else:
+                        if isinstance(streaming_response_content, JSON):
+                            streaming_response_content = streaming_response_content.text + "\n"  # type: ignore
+                        streaming_response_content += resp.content  # type: ignore
 
                 formatted_response = Markdown(streaming_response_content) if markdown else streaming_response_content  # type: ignore
                 table = Table(box=ROUNDED, border_style="blue", show_header=False)
@@ -75,7 +94,14 @@ def pprint_run_response(
 
 
 async def apprint_run_response(
-    run_response: Union[RunResponse, AsyncIterable[RunResponse], TeamRunResponse, AsyncIterable[TeamRunResponse]],
+    run_response: Union[
+        RunResponse,
+        AsyncIterable[RunResponse],
+        TeamRunResponse,
+        AsyncIterable[TeamRunResponse],
+        WorkflowRunResponse,
+        AsyncIterable[WorkflowRunResponseEvent],
+    ],
     markdown: bool = False,
     show_time: bool = False,
 ) -> None:
@@ -89,7 +115,11 @@ async def apprint_run_response(
     from agno.cli.console import console
 
     # If run_response is a single RunResponse, wrap it in a list to make it iterable
-    if isinstance(run_response, RunResponse) or isinstance(run_response, TeamRunResponse):
+    if (
+        isinstance(run_response, RunResponse)
+        or isinstance(run_response, TeamRunResponse)
+        or isinstance(run_response, WorkflowRunResponse)
+    ):
         single_response_content: Union[str, JSON, Markdown] = ""
         if isinstance(run_response.content, str):
             single_response_content = (
@@ -125,9 +155,17 @@ async def apprint_run_response(
                         or isinstance(resp, tuple(get_args(WorkflowRunResponseEvent)))
                     )
                     and hasattr(resp, "content")
-                    and isinstance(resp.content, str)
+                    and resp.content is not None
                 ):
-                    streaming_response_content += resp.content
+                    if isinstance(resp.content, BaseModel):
+                        try:
+                            streaming_response_content = JSON(resp.content.model_dump_json(exclude_none=True), indent=2)  # type: ignore
+                        except Exception as e:
+                            logger.warning(f"Failed to convert response to Markdown: {e}")
+                    else:
+                        if isinstance(streaming_response_content, JSON):
+                            streaming_response_content = streaming_response_content.text + "\n"  # type: ignore
+                        streaming_response_content += resp.content  # type: ignore
 
                 formatted_response = Markdown(streaming_response_content) if markdown else streaming_response_content  # type: ignore
                 table = Table(box=ROUNDED, border_style="blue", show_header=False)
