@@ -27,6 +27,20 @@ def is_valid_uuid(uuid_str: str) -> bool:
         return False
 
 
+def safe_content_hash(content: str) -> str:
+    """
+    Return an MD5 hash of the input string, replacing null bytes and invalid surrogates for safe hashing.
+    """
+    cleaned_content = content.replace("\x00", "\ufffd")
+    try:
+        content_hash = hashlib.md5(cleaned_content.encode("utf-8")).hexdigest()
+    except UnicodeEncodeError:
+        cleaned_content = "".join("\ufffd" if "\ud800" <= c <= "\udfff" else c for c in cleaned_content)
+        content_hash = hashlib.md5(cleaned_content.encode("utf-8")).hexdigest()
+
+    return content_hash
+
+
 def url_safe_string(input_string):
     # Replace spaces with dashes
     safe_string = input_string.replace(" ", "-")
@@ -90,8 +104,8 @@ def _clean_json_content(content: str) -> str:
     elif "```" in content:
         content = content.split("```")[1].strip()
 
-    # Remove markdown formatting
-    content = re.sub(r"[*`#]", "", content)
+    # Replace markdown formatting like *"name"* or `"name"` with "name"
+    content = re.sub(r'[*`#]?"([A-Za-z0-9_]+)"[*`#]?', r'"\1"', content)
 
     # Handle newlines and control characters
     content = content.replace("\n", " ").replace("\r", "")
@@ -108,7 +122,7 @@ def _clean_json_content(content: str) -> str:
         else:
             escaped_value = value.replace('"', '\\"')
 
-        return f'"{key.lower()}": "{escaped_value}'
+        return f'"{key}": "{escaped_value}'
 
     # Find and escape quotes in field values
     content = re.sub(r'"(?P<key>[^"]+)"\s*:\s*"(?P<value>.*?)(?="\s*(?:,|\}))', escape_quotes_in_values, content)
