@@ -32,3 +32,10 @@ class Timer:
         self.end_time = perf_counter()
         if self.start_time is not None:
             self.elapsed_time = self.end_time - self.start_time
+
+    def to_dict(self):
+        return {
+            "start_time": str(self.start_time) if self.start_time is not None else None,
+            "end_time": str(self.end_time) if self.end_time is not None else None,
+            "elapsed": self.elapsed,
+        }
