@@ -1 +1,5 @@
 from agno.vectordb.pineconedb.pineconedb import PineconeDb
+
+__all__ = [
+    "PineconeDb",
+]
